==> kdeplasma-addons-4.5.4.tar.bz2: kdeplasma-addons-4.5.4/applets/plasmaboard/BackspaceKey.h <==
/*/***************************************************************************
 *   Copyright (C) 2009 by Björn Ruberg <bjoern@ruberg-wegener.de>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef BACKSPACEKEY_H
#define BACKSPACEKEY_H

#include "FuncKey.h"

class BackspaceKey: public FuncKey {
public:
    BackspaceKey(QPoint relativePosition, QSize relativeSize);

protected:
    void paint(QPainter *painter);
};

#endif /* BACKSPACEKEY_H */

==> kdeplasma-addons-4.7.3.tar.bz2: kdeplasma-addons-4.7.3/applets/plasmaboard/BackspaceKey.h <==
/*/***************************************************************************
 *   Copyright (C) 2009 by Björn Ruberg <bjoern@ruberg-wegener.de>    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef BACKSPACEKEY_H
#define BACKSPACEKEY_H

#include "FuncKey.h"

class BackspaceKey: public FuncKey
{
public:
    BackspaceKey(QPoint relativePosition, QSize relativeSize);

protected:
    void paint(QPainter *painter);
};

#endif /* BACKSPACEKEY_H */
